==========================================
``psyclone.psyir.backend.language_writer``
==========================================

.. automodule:: psyclone.psyir.backend.language_writer

   .. contents::
      :local:

.. currentmodule:: psyclone.psyir.backend.language_writer


Classes
=======

- :py:class:`LanguageWriter`:
  A convenience PSyIR visitor intermediate class. It provides


.. autoclass:: LanguageWriter
   :members:

   .. rubric:: Inheritance
   .. inheritance-diagram:: LanguageWriter
      :parts: 1
